searchData={"items":[{"type":"module","title":"Plug.AMQP.Conn","doc":"TODO","ref":"Plug.AMQP.Conn.html"},{"type":"function","title":"Plug.AMQP.Conn.conn/3","doc":"","ref":"Plug.AMQP.Conn.html#conn/3"},{"type":"module","title":"Plug.Amqp","doc":"TODO","ref":"Plug.Amqp.html"},{"type":"function","title":"Plug.Amqp.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Plug.Amqp.html#child_spec/1"},{"type":"type","title":"Plug.Amqp.option/0","doc":"TODO","ref":"Plug.Amqp.html#t:option/0"},{"type":"type","title":"Plug.Amqp.options/0","doc":"TODO","ref":"Plug.Amqp.html#t:options/0"},{"type":"function","title":"Plug.Amqp.start_link/1","doc":"","ref":"Plug.Amqp.html#start_link/1"},{"type":"exception","title":"Plug.AMQP.UnsupportedError","doc":"","ref":"Plug.AMQP.UnsupportedError.html"},{"type":"extras","title":"PlugAmqp","doc":"# PlugAmqp\n\n[![Hex Version](https://img.shields.io/hexpm/v/plug_amqp.svg?maxAge=3600)](https://hex.pm/packages/plug_amqp)\n[![License](https://img.shields.io/hexpm/l/plug_amqp.svg?maxAge=3600)](https://hex.pm/packages/plug_amqp)\n[![Build and Test](https://github.com/kantox/plug_amqp/workflows/Build%20and%20Test/badge.svg)](https://github.com/kantox/plug_amqp/actions)\n[![Coverage Status](https://coveralls.io/repos/github/kantox/plug_amqp/badge.svg?t=2ISMwr)](https://coveralls.io/github/kantox/plug_amqp)\n\n`Plug.AMQP` provides an [AMQP](https://www.amqp.org) interface to `Plug`. When\nusing `Plug.AMQP` we can write servers that answer requests sent through an\n*AMQP* broker, like [RabbitMQ](https://www.rabbitmq.com). The request response\npattern is explained in detail\n[here](https://www.rabbitmq.com/tutorials/tutorial-six-elixir.html).\n\n[Online documentation](https://hexdocs.pm/plug_amqp/Plug.AMQP.html).","ref":"readme.html"},{"type":"extras","title":"Installation - PlugAmqp","doc":"We can use `plug_amqp` in our projects by adding the dependency:\n\n```elixir\ndef deps do\n  [\n    {:plug_amqp, \"~> 0.5\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - PlugAmqp","doc":"To use `Plug.AMQP`, add it to the supervision tree:\n\n```elixir\nchildren = [\n  {Plug.AMQP, connection_options: \"amqp://my-rabbit:5672\", plug: MyPlug}\n]\n\nSupervisor.start_link(children, strategy: :one_for_one)\n```\n\nHere it is a `Plug` as an example:\n\n```elixir\ndefmodule MyPlug do\n  @behaviour Plug\n\n  @impl true\n  def init(_opts), do: nil\n\n  @impl true\n  def call(conn, _opts) do\n    {:ok, body, conn} = Plug.Conn.read_body(conn)\n    input = String.to_integer(body)\n\n    output = fib(input)\n\n    resp_body = to_string(output)\n    Plug.Conn.send_resp(conn, 200, resp_body)\n  end\n\n  defp fib(0), do: 0\n  defp fib(1), do: 1\n  defp fib(n) when n > 1, do: fib(n - 1) + fib(n - 2)\nend\n```\n\nThen we can start sending messages to the server through *AMQP*:\n\n```elixir\n# Setting Up the RPC Request Queue\n\n{:ok, conn} = AMQP.Connection.open()\n{:ok, chan} = AMQP.Channel.open(conn)\n\n{:ok, _info} = AMQP.Queue.declare(chan, \"rpc_queue\")\n\n# Starting the Server\n\n{:ok, _adapter} = Plug.AMQP.start_link(consumer_queue: \"rpc_queue\", plug: MyPlug)\n\n# Setting the Client\n\n{:ok, %{queue: callback_queue}} = AMQP.Queue.declare(chan, \"\", exclusive: true)\n{:ok, _ctag} = AMQP.Basic.consume(chan, callback_queue, nil, no_ack: true)\n\n# Sending a Request\n\nIO.puts(\"Sending a 30 as a request\")\nAMQP.Basic.publish(chan, \"\", \"rpc_queue\", \"30\", reply_to: callback_queue)\n\n# Waiting a Response\n\nreceive do\n  {:basic_deliver, response, _meta} ->\n    IO.puts(\"Got a #{response} response\")\nend\n```\n\nCheck `Plug.AMQP` module from the\n[online documentation](https://hexdocs.pm/plug_amqp/Plug.AMQP.html) for more\ninformation. Also, take a look the examples in the `examples` folder.","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}